# -*- coding: utf-8 -*-

# main.py
# Version: python v.2.x

# Licence: GPL3

import sys

from PyQt4 import QtCore, QtGui

from miniView import MiniView
from magnifier import Magnifier

class Main(object):
    def __init__(self):
        MainWindow = QtGui.QMainWindow()
        self.ui = MiniView()
        self.ui.setupUi(MainWindow, self)
        self.magnifier_current_settings = [1.0, "square", 160]
        self.magnification = False
        self.window_geometry = MainWindow.geometry()
        self.ui.magnifier_btn.clicked.connect(self.set_magnifier)        

    def set_magnifier(self):
        self.mgnf = Magnifier(self, graphic=self.ui.viewer, 
                                    scene=self.ui.scene, 
                                    img=self.ui.image, 
                                    zoom=self.ui.zoom)       
        self.set_magnifier_options()
        self.mgnf.setup()
        self.apply_shadow_effect()
        self.mgnf.positionChanged.connect(self.on_magnifier_moved)
        self.mgnf.settingsChanged.connect(self.show_magnifier_settings)
        self.mgnf.setFocus()

    def set_magnifier_options(self):
        self.mgnf.set_factor(self.magnifier_current_settings[0])
        self.mgnf.set_shape(self.magnifier_current_settings[1])
        self.mgnf.set_size(self.magnifier_current_settings[2])
        self.show_magnifier_settings(self.magnifier_current_settings)

    def show_magnifier_settings(self, values):
        self.ui.label.setText(u"  Outil loupe, taille: {0} px, "
                            "facteur de grossissement: {1} %".format(
                            values[2], values[0] * 100))
        self.magnifier_current_settings = [values[0], str(values[1]), values[2]]

    def on_magnifier_moved(self, c):
        self.ui.statusbar.showMessage(
                            u"Loupe déplacée depuis ({0}, {1}) à ({2}, {3})" 
                            .format(c[0], c[1], c[2], c[3]))

    def apply_shadow_effect(self):
        self.shadow = QtGui.QGraphicsDropShadowEffect()
        self.shadow.setColor(QtGui.QColor(50, 50, 50, 200))
        self.shadow.setXOffset(6)
        self.shadow.setYOffset(6)
        self.shadow.setBlurRadius(3)
        self.mgnf.setGraphicsEffect(self.shadow)
        self.shadow.setEnabled(False)


if __name__ == "__main__":
    app = QtGui.QApplication(sys.argv)
    main = Main()
    sys.exit(app.exec_())
